@@ -50,6 +50,13 @@ main(void)
   int retval = 0;
   econf_err error;
 
+  if ((error = econf_newKeyFile_with_options(&key_file, "ROOT_PREFIX="TESTSDIR)))
+    {
+      fprintf (stderr, "ERROR: couldn't allocate new file: %s\n",
+	       econf_errString(error));
+      return 1;
+    }
+
   error = econf_readConfig (&key_file,
 	                    NULL,
                             "",
