@@ -13,10 +13,10 @@
 int
 main(void)
 {
-  econf_err error;  
+  econf_err error;
 
   // Read test data
-  econf_file *kf_fromfile = (econf_file *)-1;
+  __attribute__((cleanup(econf_freeFilep))) econf_file *kf_fromfile = NULL;
   error = econf_readFile(&kf_fromfile,
 			 TESTSDIR"tst-write-string-data/usr/etc/tst-string-data.conf",
 			 "=", "#");
@@ -38,7 +38,7 @@ main(void)
   econf_writeFile(kf_fromfile, TESTSDIR"tst-write-string-data/", "out.ini");
 
   // And reading it again
-  econf_file *kf_compare = (econf_file *)-1;
+  econf_file *kf_compare = NULL;
   error = econf_readFile(&kf_compare,
 			 TESTSDIR"tst-write-string-data/out.ini", "=", "#");
   if (error || kf_compare == NULL) {
@@ -69,15 +69,15 @@ main(void)
   }
 
   // Merge two econf_files. One value is a NULL value.
-  econf_file *kf_freshini = (econf_file *)-1;
+  econf_file *kf_freshini = NULL;
   econf_newIniFile(&kf_freshini);
-  econf_setStringValue(kf_freshini, "test", "test", NULL);  
-  econf_file *kf_merged = (econf_file *)-1;
+  econf_setStringValue(kf_freshini, "test", "test", NULL);
+  econf_file *kf_merged = NULL;
   econf_mergeFiles(&kf_merged, kf_freshini, kf_fromfile);
 
   econf_free(kf_freshini);
   econf_free(kf_merged);
   econf_free(kf_compare);
-  econf_free(kf_fromfile);
+
   return 0;
 }
